SNAP data plane session state.
Modules
- dto
- Data transfer objects (DTOs) for SNAP data plane session state.
Structs
- Session
- Open data plane session.
- Session
Grant - Grant for a session required to issue session tokens.
- Session
Id - SNAP data plane session ID.
- Session
Manager State - Manages data plane sessions.
- Session
Token Issuer State - Session token issuer state. Allows issuing session tokens for the opened data plane sessions depending on the SNAP token validity of the session.
Functions
- insecure_
const_ ed25519_ signing_ key - Returns a seeded Ed25519 signing key.
- insecure_
const_ session_ key_ pair - Returns a session key pair for the given SNAP ID.
- insecure_
const_ session_ key_ pair_ pem - Returns a session key pair for the given SNAP ID in PEM format.
- random_
ed25519_ signing_ key - Returns a random Ed25519 signing key.