pub fn insecure_const_session_key_pair(
input: usize,
) -> (EncodingKey, DecodingKey)Expand description
Returns a session key pair for the given SNAP ID.
Note: This is only for testing purposes.
pub fn insecure_const_session_key_pair(
input: usize,
) -> (EncodingKey, DecodingKey)Returns a session key pair for the given SNAP ID.
Note: This is only for testing purposes.