pub struct SessionManagerState { /* private fields */ }Expand description
Manages data plane sessions.
A session is identified by the pseudo SCION subscriber identity (PSSID) from the SNAP token. At any point in time, there is at most one session open with a data plane per PSSID.
Note: We might need to weaken this constraint in the future to allow multiple session per data plane to allow session failover in case only a single data plane is running.
Implementations