SessionTokenIssuerState

Struct SessionTokenIssuerState 

pub struct SessionTokenIssuerState { /* private fields */ }
Session token issuer state. Allows issuing session tokens for the opened data plane sessions depending on the SNAP token validity of the session.

Implementations

Source

impl SessionTokenIssuerState

pub fn new(key: Ed25519SigningKeyPem) -> Self

Creates a new session token issuer state with the given signing key.